@@ -9,7 +9,7 @@ from __future__ import with_statement
 
 import functools
 import optparse
-import os.path
+import os
 from pprint import pprint
 import re
 import sys
@@ -61,9 +61,9 @@ except ImportError:
         return _convert(node_or_string)
 
 
-__version__ = '1.3.1'
+__version__ = '1.4'
 __all__ = ['Client', 'Model', 'Record', 'RecordList', 'Service',
-           'format_exception', 'read_config']
+           'format_exception', 'read_config', 'start_openerp_services']
 
 CONF_FILE = 'erppeek.ini'
 HIST_FILE = os.path.expanduser('~/.erppeek_history')
@@ -215,10 +215,32 @@ def read_config(section=None):
         return p.sections()
     env = dict(p.items(section))
     scheme = env.get('scheme', 'http')
-    server = '%s://%s:%s' % (scheme, env['host'], env['port'])
+    if scheme == 'local':
+        server = (scheme, env.get('options', ''))
+    else:
+        server = '%s://%s:%s' % (scheme, env['host'], env['port'])
     return (server, env['database'], env['username'], env.get('password'))
 
 
+def start_openerp_services(options=None):
+    """Initialize the OpenERP services.
+
+    Import the ``openerp`` package and load the OpenERP services.
+    The argument `options` receives the command line arguments for ``openerp``.
+    Example: ``-c /path/to/openerp-server.conf --without-demo all``.
+    Return the openerp module.
+    """
+    import openerp
+    if not openerp.osv.osv.service:
+        os.environ['TZ'] = 'UTC'
+        options = options and options.split() or []
+        openerp.tools.config.parse_config(options)
+        openerp.netsvc.init_logger()
+        openerp.osv.osv.start_object_proxy()
+        openerp.service.web_services.start_web_services()
+    return openerp
+
+
 def issearchdomain(arg):
     """Check if the argument is a search domain.
 
@@ -270,26 +292,32 @@ def searchargs(params, kwargs=None, context=None):
     return params
 
 
-class Service(ServerProxy):
+class Service(object):
     """A wrapper around XML-RPC endpoints.
 
     The connected endpoints are exposed on the Client instance.
     The `server` argument is the URL of the server (scheme+host+port).
-    The `endpoint` argument is the last part of the URL
+    If `server` is an ``openerp`` module, it is used to connect to the
+    local server.  The `endpoint` argument is the name of the service
     (examples: ``"object"``, ``"db"``).  The `methods` is the list of methods
     which should be exposed on this endpoint.  Use ``dir(...)`` on the
     instance to list them.
     """
     def __init__(self, server, endpoint, methods, verbose=False):
-        uri = server + '/xmlrpc/' + endpoint
-        ServerProxy.__init__(self, uri, allow_none=True)
+        if isinstance(server, basestring):
+            self._rpcpath = rpcpath = server + '/xmlrpc/'
+            proxy = ServerProxy(rpcpath + endpoint, allow_none=True)
+            self._dispatch = proxy._ServerProxy__request
+        else:
+            self._rpcpath = ''
+            proxy = server.netsvc.ExportService.getService(endpoint)
+            self._dispatch = proxy.dispatch
         self._endpoint = endpoint
         self._methods = sorted(methods)
         self._verbose = verbose
 
     def __repr__(self):
-        rname = '%s%s' % (self._ServerProxy__host, self._ServerProxy__handler)
-        return '<Service %s>' % rname
+        return '<Service %r>' % (self._rpcpath + self._endpoint)
     __str__ = __repr__
 
     def __dir__(self):
@@ -313,7 +341,7 @@ class Service(ServerProxy):
                     suffix = '... L=%s' % len(snt)
                     snt = snt[:maxcol - len(suffix)] + suffix
                 print('--> ' + snt)
-                res = self._ServerProxy__request(name, args)
+                res = self._dispatch(name, args)
                 rcv = str(res)
                 if len(rcv) > maxcol:
                     suffix = '... L=%s' % len(rcv)
@@ -321,7 +349,7 @@ class Service(ServerProxy):
                 print('<-- ' + rcv)
                 return res
         else:
-            wrapper = lambda s, *args: s._ServerProxy__request(name, args)
+            wrapper = lambda s, *args: s._dispatch(name, args)
         wrapper.__name__ = name
         return wrapper.__get__(self, type(self))
 
@@ -331,6 +359,9 @@ class Client(object):
 
     This is the top level object.
     The `server` is the URL of the instance, like ``http://localhost:8069``.
+    If `server` is an ``openerp`` module, it is used to connect to the local
+    server (6.1 only).
+
     The `db` is the name of the database and the `user` should exist in the
     table ``res.users``.  If the `password` is not provided, it will be
     asked on login.
@@ -375,12 +406,14 @@ class Client(object):
         See :func:`read_config` for details of the configuration file format.
         """
         server, db, user, password = read_config(environment)
+        if server[0] == 'local':
+            server = start_openerp_services(server[1])
         client = cls(server, db, user, password, verbose=verbose)
         client._environment = environment
         return client
 
     def __repr__(self):
-        return "<Client '%s#%s'>" % (self._server, self._db)
+        return "<Client '%s#%s'>" % (self._server or '', self._db)
 
     def login(self, user, password=None, database=None):
         """Switch `user` and (optionally) `database`.
@@ -1011,7 +1044,15 @@ class Model(object):
 
 
 class RecordList(object):
-    """A sequence of OpenERP :class:`Record`."""
+    """A sequence of OpenERP :class:`Record`.
+
+    It has a similar API as the :class:`Record` class, but for a list of
+    records.  The attributes of the ``RecordList`` are read-only, and they
+    return list of attribute values in the same order.  The ``many2one``,
+    ``one2many`` and ``many2many`` attributes are wrapped in ``RecordList``
+    and list of ``RecordList`` objects.  Use the method ``RecordList.write``
+    to assign a single value to all the selected records.
+    """
 
     def __init__(self, res_model, ids, context=None):
         _ids = []
@@ -1132,16 +1173,15 @@ class Record(object):
 
     It maps any OpenERP object.
     The fields can be accessed through attributes.  The changes are immediately
-    saved in the database.
-    The ``many2one``, ``one2many`` and ``many2many`` attributes are followed
-    when the record is read.  However when writing in these relational fields,
-    use the appropriate syntax described in the official OpenERP documentation.
+    sent to the server.
+    The ``many2one``, ``one2many`` and ``many2many`` attributes are wrapped in
+    ``Record`` and ``RecordList`` objects.  These attributes support writing
+    too.
     The attributes are evaluated lazily, and they are cached in the record.
-    The cache is invalidated if the :meth:`~Record.write` or the
-    :meth:`~Record.unlink` method is called.
+    The Record's cache is invalidated if any attribute is changed.
     """
     def __init__(self, res_model, res_id, context=None):
-        if isinstance(res_id, list):
+        if isinstance(res_id, (list, tuple)):
             (res_id, res_name) = res_id
             self.__dict__['_name'] = res_name
         # Bypass the __setattr__ method
@@ -1282,8 +1322,6 @@ class Record(object):
         if attr == 'id':
             raise AttributeError("'Record' object attribute 'id' is read-only")
         self.write({attr: value})
-        if attr in self.__dict__:
-            delattr(self, attr)
 
 
 def _interact(use_pprint=True, usage=USAGE):
